package com.sun.org.apache.xml.internal.security.signature;

import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;
import org.w3c.dom.Attr;
import com.sun.org.apache.xml.internal.security.utils.XMLUtils;
import org.w3c.dom.Element;
import org.w3c.dom.Document;
import com.sun.org.apache.xml.internal.security.utils.SignatureElementProxy;

public class SignatureProperties extends SignatureElementProxy
{
    public SignatureProperties(Document doc) {
        super(doc);
        this.addReturnToSelf();
    }
    
    public SignatureProperties(Element element, String baseURI) throws XMLSecurityException {
        super(element, baseURI);
        Attr attributeNodeNS = element.getAttributeNodeNS(null, "Id");
        if (attributeNodeNS != null) {
            element.setIdAttributeNode(attributeNodeNS, true);
        }
        for (int length = this.getLength(), i = 0; i < length; ++i) {
            Element selectDsNode = XMLUtils.selectDsNode(this.getElement(), "SignatureProperty", i);
            Attr attributeNodeNS2 = selectDsNode.getAttributeNodeNS(null, "Id");
            if (attributeNodeNS2 != null) {
                selectDsNode.setIdAttributeNode(attributeNodeNS2, true);
            }
        }
    }
    
    public int getLength() {
        return XMLUtils.selectDsNodes(this.getElement(), "SignatureProperty").length;
    }
    
    public SignatureProperty item(int number) throws XMLSignatureException {
        try {
            Element selectDsNode = XMLUtils.selectDsNode(this.getElement(), "SignatureProperty", number);
            if (selectDsNode == null) {
                return null;
            }
            return new SignatureProperty(selectDsNode, this.baseURI);
        }
        catch (XMLSecurityException ex) {
            throw new XMLSignatureException(ex);
        }
    }
    
    public void setId(String value) {
        if (value != null) {
            this.setLocalIdAttribute("Id", value);
        }
    }
    
    public String getId() {
        return this.getLocalAttribute("Id");
    }
    
    public void addSignatureProperty(SignatureProperty toAppend) {
        this.appendSelf(toAppend);
        this.addReturnToSelf();
    }
    
    @Override
    public String getBaseLocalName() {
        return "SignatureProperties";
    }
}
